
var request = require('request')
  , url 	= require('url');

var API_BASE_URL = "http://api.browserstack.com/3/";

function browserStackAPIClient(userName, apiKey){

	
	if(userName && apiKey){

		this.request = request.defaults({

		    auth: {

		      username: userName,
		      password: apiKey
		    }
	  	});	
	}
	else{

		console.log("Please specify username && your api key in configuration file");
	}
	
}

var responseFormatting = function(callback){

	return function(err, response, body){
		
		if(err){

      		callback(err, null);
    	}else if(response.statusCode !== 200 && response.statusCode !== 201){
     		
     		callback({statusCode: response.statusCode, body: body}, null);

    	}else {

      		callback(null, JSON.parse(body.toString()));
    	}
	};
}

browserStackAPIClient.prototype.getAPIStatus = function(callback){

	
	var getUrl = API_BASE_URL+'status';

	this.request.get({

	    url: getUrl
	}, responseFormatting(callback));
}

browserStackAPIClient.prototype.createWorker = function(options, callback){

	var workerUrl = API_BASE_URL+'worker';
	
	this.request.post({

	    url: workerUrl,
	    body: JSON.stringify(options),
	    headers: {
	    	
	      'Content-Type': 'application/json'
	    }
	}, responseFormatting(callback));
}

browserStackAPIClient.prototype.deleteWorker = function(workerId, callback){

	var workerUrl = url.parse(API_BASE_URL+'worker/'+workerId);

	this.request.del({

    	url: workerUrl
  	}, responseFormatting(callback));
}

browserStackAPIClient.prototype.getWorkerStatus = function(workerId, callback){

	var workerUrl = url.parse(API_BASE_URL+'worker/'+workerId);
		

	this.request.get({

    	url: workerUrl
  	}, responseFormatting(callback));
}

browserStackAPIClient.prototype.getAllWorkersStatus = function(workerId, callback){

	var workerUrl = API_BASE_URL+'workers/'+workerId+;

	this.request.get({

    	url: workerUrl
  	}, responseFormatting(callback));
}


browserStackAPIClient.prototype.getScreenshotOfCurrentStateOfWorker = function(workerId, format, callback){

	var workerUrl = url.parse(API_BASE_URL+'worker/'+workerId+'/screenshot');

	this.request.get({

    	url: workerUrl,
    	headers: {
	    	
	      'Content-Type': 'text/json'
	    }
  	}, responseFormatting(callback));

}

browserStackAPIClient.prototype.getBrowsers = function(param, callback){

	if(param == 'all'){

		var getUrl = API_BASE_URL+'browsers?all=true';
	}
	else if(param == 'flat'){

		var getUrl = API_BASE_URL+'browsers?flat=true';
	}
	else{

		var getUrl = API_BASE_URL+'browsers';
	}

	this.request.get({

	   url: getUrl
	}, responseFormatting(callback));
}


module.exports = browserStackAPIClient;